% Read panel pressure distribution from Wadam
% Written by Vetle Kallaak

% panels(panel,1:10) Geometry of panels
% 1:10 - PI, PANO, NX, NY, NZ, XC, YC, ZC, A, DIAG 
% Ppanels(panel,1:6,wave) Pressure on panels
% 1:6 - PI, PANO, REAL, IMAG, ABS, PHASE

function [WaveDat, panels, Ppanels, PpanelsR, sections] = PanelsWadamLIS(workspace)
%workspace = 'windFloat_test2';
fname = ['C:\DNVGL\Workspaces\HydroD\' workspace '\WADAM1.LIS']; 

fid = fopen(fname);
A = textscan(fid,'%s','Delimiter','\n');
data = A{1};
fclose(fid);
clear A

% Number of panels
n=0;
found=0;
ii = 1;
while ii<length(data) && found == 0
    k = strfind(data(ii), 'NUMBER OF BASIC PANELS GENERATED');
    if ~isempty(k{1})
        n = ii;
        found = 1;
        C = split(data{ii},': ');
        numPanel = str2double(C(2));
    end
    ii=ii+1;
end

% Wave data
ii=n;
found = 0;
while ii<length(data) && found == 0
    k = strfind(data(ii), 'ENVIRONMENTAL DATA:');
    if ~isempty(k{1})
        n = ii;
        found = 1;
        C = textscan(data{ii+3},'%s %s %s %f %s');
        waterdepth = C{4};
        C = textscan(data{ii+4},'%s %s %s %s %s %f ');    
        numwavelengths = C{6};
        C = textscan(data{ii+5},'%s %s %s %s %s %f ');    
        numheadangles = C{6};
        WaveDat = zeros(numwavelengths,5);
        WaveDir = zeros(numheadangles,3);
        for kk = 1:numwavelengths
            % Wave#, wave length, wave number, wave period, wave ang. freq.
            WaveDat(kk,:) = str2num(data{ii+kk+12});
        end
        for jj = 1:numheadangles
            WaveDir(jj,:) = str2num(data{ii+kk+jj+12+7});
        end
    end
    ii = ii+1;
end    


% Panel data
ii = n; 
found = 0;
panels = zeros(numPanel, 14);

while ii<length(data) && found == 0
    k = strfind(data(ii), 'PI   PANO IVER X');
    if ~isempty(k{1})
        found = 1; 
        cc=ii+4; 
        p = 1; % Panel
        while p <= numPanel
            line = data{cc};
            if length(str2num(line)) > 5 % Just the lines with data about the panel
                line = split(line);
                col=1;
                for ss = 1:length(line) % Each data field
                    if count(line(ss),'.') > 1
                        a=strfind(line(ss),'.');
                        panels(p,col) = str2double(extractBefore(line(ss),a(2)-2));
                        col=col+1;
                        if length(a) > 2
                            for dots=2:(length(a)-1)
                            panels(p,col) = str2double(extractBetween(line(ss),a(dots)-2,a(dots+1)-3));
                            col=col+1;
                            end
                        end
                        panels(p,col) = str2double(extractAfter(line(ss),a(end)-3));
                        col=col+1;
                    else
                        panels(p,col) = str2double(line(ss));
                        col=col+1;
                    end
                end
                p=p+1; % Read one panel
            end
            cc = cc+1;
        end
        n = cc;
    end
    ii = ii+1;
end
panels(:,3:6) = [];
% PI, PANO, NX, NY, NZ, XC, YC, ZC, A, DIAG 


% Non dimensionalized parameters
ii = n; 
found = 0;
while ii<length(data) && found == 0
    k = strfind(data(ii), 'THE OUTPUT IS NON-DIMENSIONALIZED USING');
    if ~isempty(k{1})
        n = ii;
        found = 1;
         C = textscan(data{ii+8},'%s %s %f');
         RO   =  C{3};
         C = textscan(data{ii+9},'%s %s %f');
         G   =  C{3};
         C = textscan(data{ii+10},'%s %s %f');
         VOL   =  C{3}; % Displaced volume
         C = textscan(data{ii+11},'%s %s %f');
         L   =  C{3} ; % Characterisitc length       
         C = textscan(data{ii+12},'%s %s %f');
         WA   =  C{3} ; % Wave amplitude
    end
    ii = ii+1;
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% For each wave condition
nstart = n;  

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Basic part  

Ppanels = zeros(numPanel,11,numwavelengths);
ii = nstart;
for nn = 1:numwavelengths
    found = 0;
    while ii<length(data) && ~found        
        k = strfind(data(ii), 'BASIC PART    ');    
        if ~isempty(k{1})
            found = 1;
            cc=ii+6; 
            p = 1; % Panel
            while p <= numPanel
                line = str2num(data{cc});
                if length(line) > 9
                    Ppanels(p,:,nn) = line;
                    p=p+1; % Read one panel
                end
                cc = cc+1;
            end
           % n = cc;
        end
        ii = ii+1;
    end
end
       
% Giving right dimenisons
Ppanels(:,3:7,:) = [];
Ppanels(:,3:5,:) = Ppanels(:,3:5,:)*RO*G*WA;
% PI, PANO, REAL, IMAG, ABS, PHASE (DEG)


% Reflection 
PpanelsR = zeros(numPanel,11,numwavelengths);
ii = nstart;
for nn = 1:numwavelengths
    found = 0;
    while ii<length(data) && ~found        
        k = strfind(data(ii), 'REFLECTION    ');    
        if ~isempty(k{1})
            found = 1;
            cc=ii+6; 
            p = 1; % Panel
            while p <= numPanel
                line = str2num(data{cc});
                if length(line) > 9
                    PpanelsR(p,:,nn) = line;
                    p=p+1; % Read one panel
                end
                cc = cc+1;
            end
           n = cc;
        end
        ii = ii+1;
    end
end
       
% Giving right dimenisons
PpanelsR(:,3:7,:) = [];
PpanelsR(:,3:5,:) = PpanelsR(:,3:5,:)*RO*G*WA;
% PI, PANO, REAL, IMAG, ABS, PHASE (DEG)


% Read cross section calculations from Wadam
sections = zeros(6,6,numwavelengths);
ii = n;
for nn = 1:numwavelengths
    found = 0;
    while ii<length(data) && ~found        
        k = strfind(data(ii), 'PRESSURE LOADS');    
        if ~isempty(k{1})
            found = 1;
            for qq = 1:6
                dat = textscan(data{ii+qq+2},'%s %f %f %f %f %f %f');
                sections(qq,:,nn) = [dat{2} dat{3} dat{4} dat{5} dat{6} dat{7}];
            end                   
        end
        ii = ii+1; 
    end
end
sections(1:3,1:5,:) = sections(1:3,1:5,:)*RO*VOL*G*WA/L;
sections(4:6,1:5,:) = sections(4:6,1:5,:)*RO*VOL*G*WA;

end % Function