% Wind Turbine Data
%Written by Vetle Kallaak

function [data] = WTdata(towerBase)
%towerBase = 8.63;

% % NREL 5MW
% data.masstot = 697000; %Roddier
% data.masstot = 599718; % Kvittem (OC3 tower)
% data.Ft = 800*10^3;
% data.hubh = 90;
% data.COGx = -0.2; 
% data.COGy = 0.0; 
% data.COGz = 64;
% data.Dbot = 8;

% % DTU 10 MW RWT
data.Ft = 1500*10^3;
data.hubh = 119;

% % Tower properties
hTower = 115.63 - towerBase; % Tower length
tTower = 0.04; % Tower thickness
Dtop = 5.5; % Diameter tower top
Dbot = 10.5; % Diameter tower base
Dbot = Dbot + (Dbot-Dtop)/hTower*(hTower-107);
% Volume of tower
V_tower = 1/3*pi*hTower*1/4*(Dbot^2+Dbot*Dtop+Dtop^2) - ...
    1/3*pi*hTower*((Dbot/2-tTower)^2+(Dbot/2-tTower)*(Dtop/2-tTower)+(Dtop/2-tTower)^2);
M_tower = 8500 * V_tower;

V_z = 1/12*pi*hTower^2*1/4*(Dbot^2+2*Dbot*Dtop+3*Dtop^2) - ...
    1/12*pi*hTower^2*((Dbot/2-tTower)^2+2*(Dbot/2-tTower)*(Dtop/2-tTower)+3*(Dtop/2-tTower)^2);
COG_tower = [0.0, 0.0, V_z/V_tower];

% DTU 10MW RWT tower
% M_tower = 628442;
% COG_tower = [0.0, 0.0, 47.6];

% Rotor (Hub+blades)
M_rot = 227962;
COG_rot = [-7.07, 0, data.hubh];

% Nacelle
M_nac = 446036;
COG_nac = [2.687, 0, 118.08];

% Total WT
M_tot=M_rot+M_nac+M_tower;
COG = (M_rot*COG_rot+M_nac*COG_nac+M_tower*COG_tower)/M_tot;

data.masstot = M_tot;
data.COGx = COG(1); 
data.COGy = COG(2); 
data.COGz = COG(3);
data.mtower = M_tower;
data.COGztower = COG_tower(3);
data.Dbot = Dbot
end
