function [eta1, eta0, FtotwI, FtotwD, Atot_mor, Btot_mor, F_hp1, B_hp1] = ...
    includeMorisonElem(p, elem, alpha, env, M, C,...
    waveW, ADDMASS, DAMPING, F_pot)
fprintf('Calculating Morison...\n');
%%
h_approx = 0.4; % Integration length/steps for Morison along each element
COC = [0 0 0]; % Center of coordinate system, for calculating moments and motions
% For bracings
diaBracHor = p.diaBracing/sin(alpha); % Horizontal cross section, max dia
lBracW = (-p.COGz_pon - p.diaBeam/2)/sin(alpha); % Wet length of bracing
% For calculating start and end for bracings
dBSx = diaBracHor/2*cos(pi/6);
dBSy = diaBracHor/2*sin(pi/6);
dBEx = dBSx+lBracW*cos(alpha)*cos(pi/6);
dBEy = dBSy+lBracW*cos(alpha)*sin(pi/6);

% coord - Description of Morison elements
% Row: Morison element
% Columns: (x,y,z) start and then end of Morison element (keep normal
% vector positiv). Column 7: Diameter, 8: C_a, 9: C_D
coord = [elem(2).COG(1)+p.diaCol/2*cos(pi/6), elem(2).COG(2)-p.diaCol/2*sin(pi/6), p.COGz_pon, elem(1).COG(1)-p.diaCol/2*cos(pi/6), elem(1).COG(2)+p.diaCol/2*sin(pi/6), p.COGz_pon, p.diaBeam, 1, 1;
elem(3).COG(1), elem(3).COG(2)+p.diaCol/2, p.COGz_pon, elem(2).COG(1), elem(2).COG(2)-p.diaCol/2, p.COGz_pon, p.diaBeam, 1, 1;
elem(3).COG(1)+p.diaCol/2*cos(pi/6), elem(3).COG(2)+p.diaCol/2*sin(pi/6), p.COGz_pon, elem(1).COG(1)-p.diaCol/2*cos(pi/6), elem(1).COG(2)-p.diaCol/2*sin(pi/6), p.COGz_pon, p.diaBeam,1,1;
elem(4).COG(1),elem(4).COG(2),elem(4).COG(3),elem(4).COG(1),elem(4).COG(2),elem(4).COG(3),sqrt(elem(4).A/pi)*2,0,7.5;
elem(5).COG(1),elem(5).COG(2),elem(5).COG(3),elem(5).COG(1),elem(5).COG(2),elem(5).COG(3),sqrt(elem(5).A/pi)*2,0,7.5;
elem(6).COG(1),elem(6).COG(2),elem(6).COG(3),elem(6).COG(1),elem(6).COG(2),elem(6).COG(3),sqrt(elem(6).A/pi)*2,0,7.5;
elem(10).COG(1)+dBSx, elem(10).COG(2)-dBSy, p.COGz_pon+p.diaBeam/2, elem(10).COG(1)+dBEx, elem(10).COG(2)-dBEy, 0, p.diaBracing,1,1; 
elem(10).COG(1)-dBSx, elem(10).COG(2)+dBSy, p.COGz_pon+p.diaBeam/2, elem(10).COG(1)-dBEx, elem(10).COG(2)+dBEy, 0, p.diaBracing,1,1;
elem(11).COG(1)+dBSx, elem(11).COG(2)+dBSy, p.COGz_pon+p.diaBeam/2, elem(11).COG(1)+dBEx, elem(11).COG(2)+dBEy, 0, p.diaBracing,1,1;
elem(11).COG(1)-dBSx, elem(11).COG(2)-dBSy, p.COGz_pon+p.diaBeam/2, elem(11).COG(1)-dBEx, elem(11).COG(2)-dBEy, 0, p.diaBracing,1,1;
elem(12).COG(1), elem(12).COG(2)+diaBracHor/2, p.COGz_pon+p.diaBeam/2, elem(12).COG(1), elem(12).COG(2)+diaBracHor/2+lBracW*cos(alpha), 0, p.diaBracing, 1, 1;
elem(12).COG(1), elem(12).COG(2)-diaBracHor/2, p.COGz_pon+p.diaBeam/2, elem(12).COG(1), elem(12).COG(2)-diaBracHor/2-lBracW*cos(alpha), 0, p.diaBracing, 1, 1];
%%
if p.tilt ~= 0 % New coordinates for tilted platform
    newcoords(:,1) = coord(:,1)*cos(p.tilt) + coord(:,3)*sin(p.tilt);
    newcoords(:,2) = coord(:,2);
    newcoords(:,3) = -coord(:,1)*sin(p.tilt) + coord(:,3)*cos(p.tilt);

    newcoords(:,4) = coord(:,4)*cos(p.tilt) + coord(:,6)*sin(p.tilt);
    newcoords(:,5) = coord(:,5);
    newcoords(:,6) = -coord(:,4)*sin(p.tilt) + coord(:,6)*cos(p.tilt);
    %% Bracing to surface or to column
    Delta = -(newcoords(7:12,3)./(newcoords(7:12,6)-newcoords(7:12,3)));
    Nnew(:,1:3) = (newcoords(7:12,4:6)-newcoords(7:12,1:3)).*Delta + newcoords(7:12,1:3);
    %% Check if bracing is under water and should stopped at column
    for ii=1:length(Nnew(:,1))
        if abs(Nnew(ii,2)) < elem(1).COG(2) + p.diaCol/2*sin(pi/6) % To surface or column
            Delta = (sign(Nnew(ii,2))*(elem(1).COG(2)+p.diaCol/2*sin(pi/6))-newcoords(6+ii,2))/ (newcoords(6+ii,5)-newcoords(6+ii,2));
            Nnew(ii,1:3) = (newcoords(6+ii,4:6)-newcoords(6+ii,1:3)).*Delta + newcoords(6+ii,1:3);
        elseif abs(Nnew(ii,2)) > elem(2).COG(2) - p.diaCol/2*sin(pi/6) && Nnew(ii,1) > elem(5).COG(1) % To surface or Column
            Delta = (sign(Nnew(ii,2))*(elem(2).COG(2)-p.diaCol/2*sin(pi/6))-newcoords(6+ii,2))/ (newcoords(6+ii,5)-newcoords(6+ii,2));
            Nnew(ii,1:3) = (newcoords(6+ii,4:6)-newcoords(6+ii,1:3)).*Delta + newcoords(6+ii,1:3);
        elseif abs(Nnew(ii,2)) > elem(2).COG(2) - p.diaCol/2 && Nnew(ii,1) < elem(5).COG(1) % To surface or Column
            Delta = (sign(Nnew(ii,2))*(elem(2).COG(2)-p.diaCol/2)-newcoords(6+ii,2))/ (newcoords(6+ii,5)-newcoords(6+ii,2));
            Nnew(ii,1:3) = (newcoords(6+ii,4:6)-newcoords(6+ii,1:3)).*Delta + newcoords(6+ii,1:3);
        end
    end
    newcoords(7:12,4:6) = Nnew
    coord(:,1:6) = newcoords;
    
end
%%
% First iteration of motions with Morison's equation
firstIter = true;
eta0=zeros(6,length(waveW)); % eta;

tic
[FtotwI, FtotwD, Atot_mor, Btot_mor, F_hp1, B_hp1] = ...
    morison(firstIter, waveW, eta0, env, p, h_approx, COC, coord);

% Independent of motions 
amassTot = ADDMASS+Atot_mor; % Total added mass matrix for structure
F_potI = F_pot+FtotwI; % Potential forces from Wadam and inertia forces from Morison

% Depend on motions
dampingTot = DAMPING+Btot_mor;
FexcTot = F_potI+FtotwD;

[eta1] = calcRAO(waveW, M, amassTot, dampingTot, C, FexcTot);
firstIter = false;
c = 1;
%% Iteration with Morison equation 
while max(max(abs(abs(eta1(1:3,:))-abs(eta0(1:3,:))))) > 0.05 || max(max(abs(abs(eta1(4:6,:))-abs(eta0(4:6,:))))) > 0.001
    eta0 = eta1;
    
    [~, FtotwD, ~, Btot_mor, F_hp1, B_hp1] = ...
        morison(firstIter, waveW, eta0, env, p, h_approx, COC, coord);
    c = c+1;
    dampingTot = DAMPING+Btot_mor;
    FexcTot = F_potI+FtotwD;
    [eta1] = calcRAO(waveW, M, amassTot, dampingTot, C, FexcTot);
end
time = toc;

fprintf('Morison calculated. %d iterations. Time: %0.2f sec\n',c,time);

end % Function 