% Calculate internal loads
% Written by Vetle Kallaak
function [numEl, Fp, Fc, F_Mhp1, FI, Fcs] = internalLoads(sesam, p, elem, env, waveW, ...
    waveWhr, F_hp1, B_hp1, eta1, ADDMASS, DAMPING, etaM1, etaW, etaW_Bex, F_pot)
fprintf('Calculating internal loads...\n');
%% Read pressure from WADAM1.LIS
tic
[WaveDat, panels, Ppanels, PpanelsR, sections] = PanelsWadamLIS(sesam.wadam2); % ws
toc
% panels(panel,1:10) Geometry of panels
% 1:10 - PI, PANO, NX, NY, NZ, XC, YC, ZC, A, DIAG 
% Ppanels(panel,1:6,wave) Pressure on panels
% 1:6 - PI, PANO, REAL, IMAG, ABS, PHASE
%% Geometry of reflected part of structure in Sesam,symmetry about xz-plane
panelsR = panels;
panelsR(:,4)=panelsR(:,4)*-1;
panelsR(:,7)=panelsR(:,7)*-1;
numEl = length(panels(:,1));

%% Loads
FpW = zeros(6,length(WaveDat(:,1))); % Pressure loads
FradW = zeros(6,length(WaveDat(:,1))); % Radiation loads Wadam
Frad = zeros(6,length(WaveDat(:,1))); % Radiation loads
FradWBex = zeros(6,length(WaveDat(:,1))); % Radiation loads Wadam with extra damping
FI = zeros(6,length(waveWhr)); % Inertia loads
Fc = zeros(6,length(waveWhr)); % Restoring loads
F_Mhp1 = zeros(6,length(waveWhr)); % Morison drag on heave plate

% Cross section, moment point, now yz-plane
CS = [0 0 0];

for ii=1:length(WaveDat(:,1)) % All wave freq calculated in Wadam  
    % Pressure loads on panels
    for nn=1:length(panels(:,1)) %All panels
         % Only panels from colum 1
    if panels(nn,6) >= ((elem(1).COG(1) - p.lhp - 0.5)*cos(p.tilt) + ...
            -p.draft*sin(p.tilt))
        % Forces
        % F = n * area * P
        F_p = panels(nn,9) * complex(Ppanels(nn,3,ii),Ppanels(nn,4,ii));
        F_pR = panelsR(nn,9) * complex(PpanelsR(nn,3,ii),PpanelsR(nn,4,ii));
        FpW(1,ii) = FpW(1,ii) + panels(nn,3) * F_p + panelsR(nn,3) * F_pR;
        FpW(2,ii) = FpW(2,ii) + panels(nn,4) * F_p + panelsR(nn,4) * F_pR; 
        FpW(3,ii) = FpW(3,ii) + panels(nn,5) * F_p  + panelsR(nn,5) * F_pR;
        % Moments
        FpW(4,ii) = FpW(4,ii) - panels(nn,4)*F_p*(panels(nn,8)-CS(3))  -  ...
          panelsR(nn,4)*F_pR*(panelsR(nn,8)-CS(3)) + panels(nn,5)*F_p* ...
          (panels(nn,7)-CS(2)) + panelsR(nn,5)*F_pR*(panelsR(nn,7)-CS(2));
        FpW(5,ii) = FpW(5,ii) + panels(nn,3)*F_p*(panels(nn,8)-CS(3)) + ...
            panelsR(nn,3)*F_pR*(panelsR(nn,8)-CS(3)) - panels(nn,5)*F_p* ...
            (panels(nn,6)-CS(1)) - panelsR(nn,5)*F_pR*(panelsR(nn,6)-CS(1));
        FpW(6,ii) = FpW(6,ii) - panels(nn,3)*F_p*(panels(nn,7)-CS(2)) - ...
            panelsR(nn,3)*F_pR*(panelsR(nn,7)-CS(2)) + panels(nn,4)*F_p* ...
            (panels(nn,6)-CS(1)) + panelsR(nn,4)*F_pR*(panelsR(nn,6)-CS(1));
    end
    end  
    w = WaveDat(ii,5);
    % Radiation loads, part of pressure forces
    % Forces for entire wet body
    FradW(:,ii) = ADDMASS(:,:,ii)*(-w^2*etaW(:,ii)) ...
        + DAMPING(:,:,ii)*(1i*w*etaW(:,ii)); % Wadam 
    FradWBex(:,ii) = ADDMASS(:,:,ii)*(-w^2*etaW_Bex(:,ii)) ...
        + DAMPING(:,:,ii)*(1i*w*etaW_Bex(:,ii)); % Wadam with extra damping
    Frad(:,ii) = ADDMASS(:,:,ii)*(-w^2*etaM1(:,ii)) ...
        + DAMPING(:,:,ii)*(1i*w*etaM1(:,ii)); % True 
end % All wave freq calculated in Wadam
% Excitation loads
Fexc = FpW + FradWBex;

% Interpolate pressure forces for better resolution 
for r = 1:6 
    Fp(r,:) = interp1(waveW,FpW(r,:),waveWhr,'spline');
end

for ii = 1:length(waveWhr) % For all frequencies
    % Inertia forces
    % Only column 1
    w = waveWhr(ii); % Wave freq
    mz_g=0; % Mass moment for colum 1
    for e=[1 4 19 22] % NB! only want colum, hp, WT, ballast
        fix = elem(e).mass * -w^2 * ...
            (eta1(1,ii)+eta1(5,ii)*elem(e).COG(3)-eta1(6,ii)*elem(e).COG(2));
        fiz = elem(e).mass * -w^2 * ...
            (eta1(3,ii)+eta1(4,ii)*elem(e).COG(2)-eta1(5,ii)*elem(e).COG(1));
        FI(1,ii) = FI(1,ii) + fix;
        FI(3,ii) = FI(3,ii) + fiz;
        FI(5,ii) = FI(5,ii) + fix*(elem(e).COG(3)-CS(3))...
            - fiz*(elem(e).COG(1)-CS(1));
        mz_g = mz_g + elem(e).mass*elem(e).COG(3); % Mass center z
    end
    % Restoring loads (as external force)
    Fc(1,ii) = 0; % -C(1,1)*eta1(1,i); Neglect!
    % C33, C34, C35
    Fc(3,ii) = -env.rho*env.g*elem(1).A *...
        (eta1(3,ii)+eta1(4,ii)*elem(1).COG(2)-eta1(5,ii)*elem(1).COG(1));
    % C53, C54, C55
    z_b = (elem(1).Vwet*(-p.draft+p.hhp)/2+elem(4).Vwet*elem(4).COG(3)) ...
        / (elem(1).Vwet+elem(4).Vwet); % Buoyancy center z
    Fc(5,ii) = -Fc(3,ii)*(elem(1).COG(1)-CS(1)) - ...
        (env.rho*env.g*(elem(1).Vwet+elem(4).Vwet)*z_b-mz_g*env.g)*eta1(5,ii);
    % Morison drag loads on heave plate
    % Moments are about global origin
    F_Mhp1(:,ii) = F_hp1(:,ii) - B_hp1(:,:,ii)*(1i*w*eta1(:,ii));
end % Wave freq

% External forces
Fex = Fp + Fc + F_Mhp1;
% Forces at cross section from part A:
Fcs = (FI - Fex);
toc
fprintf('Internal forces calculated. numEl = %d\n', numEl);
end
