% Written by Vetle Kallaak
function control = writeSesamFiles(sesam, p, mesh, env, waves, C, mdata, Bex, run)
% Make workspace folders for Sesam runs
% Create/edit command files for GeniE and HydroD
% Save input parameters to text file
control = true;
if run == 1
    %% Create workspace folders
    statusGf = mkdir('C:\DNVGL\Workspaces\GeniE', sesam.workspace);
    statusHf = mkdir('C:\DNVGL\Workspaces\HydroD', sesam.workspace);

    %% Save input parameters
    if statusGf && statusHf
        %%
        fid = fopen(['C:\DNVGL\Workspaces\HydroD\' sesam.workspace '\input.txt'] ,'w');
        fprintf(fid,'Parameters:\n');
        fn = fieldnames(p);
        for ii = 1:numel(fn)
            if strcmp(fn{ii}, 'WT')
                fprintf(fid, 'WT_mass = %0.3f;\nWT_COGz = %0.2f;\n',p.WT.masstot,p.WT.COGz);
            else
                fprintf(fid, '%s = %0.3f;\n',fn{ii},p.(fn{ii}));
            end
        end

        fprintf(fid,'\nProperties:\n');
        fn = fieldnames(mdata);
        for ii = 1:numel(fn)
            if numel(mdata.(fn{ii})) > 1
                for jj = 1:numel(mdata.(fn{ii}))
                    fprintf(fid, '%s_%d= %0.3f;\n',fn{ii},jj,mdata.(fn{ii})(jj));
                end
            else
                fprintf(fid, '%s = %0.3f;\n',fn{ii},mdata.(fn{ii}));
            end
        end
        
        fprintf(fid, 'C33 = %0.3f;\n',C(3,3));
        fprintf(fid, 'C44 = %0.3f;\n',C(4,4));
        fprintf(fid, 'C55 = %0.3f;\n',C(5,5));

        fprintf(fid,'\nMesh:\n');
        fn = fieldnames(mesh);
        for ii = 1:numel(fn)
            fprintf(fid, '%s= %0.2f;\n',fn{ii}, mesh.(fn{ii}));
        end
        
        time = datestr(clock,'YYYY/mm/dd HH:MM:SS:FFF');
        fprintf(fid,'\n\n%23s\n',time);

        status=fclose(fid);
        if status ~= 0
            fprintf('Did not close file!\n');
            control = false;
        end
    else
        disp('Did not make new workspace folders');
        control = false;
    end
    %% GeniE command file
    fidG1 = fopen('C:\Users\Vetle\OneDrive  NTNU\Emner\MASTER\GeniE_windFloat_matlab.js','r');
    A = textscan(fidG1,'%s','Delimiter','\n');
    data = A{1};
    status=fclose(fidG1);
    if status ~= 0
        fprintf('Did not close file!\n');
        control = false;
    end
    clear A;

    % Change input data in GeniE command file
    data{18} = ['numCol = ' num2str(p.numCol) '; // Number of columns'];
    data{19} = ['draft = ' num2str(p.draft) 'm; // Floater draft'];
    data{20} = ['diaCol = ' num2str(p.diaCol) 'm; // Column diameter'];
    data{21} = ['FB1 = ' num2str(p.FBM) 'm; // Modeled freebord'];
    data{22} = ['dcc = ' num2str(p.dcc) 'm; // Distance center-center columns'];
    data{23} = ['lhp = ' num2str(p.lhp) 'm; // Heave plate length of plate edge (hexagon)'];
    data{24} = ['hhpM = ' num2str(p.hhpM) 'm; // Modeled height of heave plate'];

    data{27} = ['numElWL2 = ' num2str(mesh.numElWL2) '; // Elemenents on WL column 2'];
    data{28} = ['Mesh_Length_P = ' num2str(mesh.gensize) 'm; // General mesh size'];
    data{29} = ['Mesh_max = ' num2str(mesh.maxsize) 'm; // Max mesh size, for under hp'];
    
    %fidG2 = fopen('C:\Users\Vetle\OneDrive  NTNU\Emner\MASTER\testGeniE.js','w');
    fidG2 = fopen('C:\DNVGL\Workspaces\GeniE\GeniE_fromMatlab.js','w');
    for ii = 1:numel(data)
            fprintf(fidG2,'%s\n', data{ii});
    end
    status=fclose(fidG2);
    if status ~= 0
        fprintf('Did not close file!\n');
        control = false;
    end

    %% HydroD command file 
    fidH1 = fopen('C:\Users\Vetle\OneDrive  NTNU\Emner\MASTER\HydroD_windFloat_matlab.js','r');
    A = textscan(fidH1,'%s','Delimiter','\n');
    data = A{1};
    status=fclose(fidH1);
    if status ~= 0
        fprintf('Did not close file!\n');
        control = false;
    end
    clear A;

    % Change input data in HydroD command file
    data{6} = ['g = ' num2str(env.g) ' m/s^2; // Gravity'];
    data{7} = ['rho = ' num2str(env.rho) ' Kg/m^3; // Sea water density'];
    data{8} = ['d = ' num2str(env.d) ' m; // Depth'];
    data{10} = ['totMass = ' num2str(mdata.massM) ' Kg; // Modeled mass'];
    for ii = 1:3
        data{10+ii} = ['COG_' num2str(ii) ' = ' num2str(mdata.COG(ii)) ' m; // Center of gravity'];
        data{10+3+ii} = ['r_' num2str(ii) ' = ' num2str(mdata.r(ii)) ' m; // Radius of gyration'];
        data{10+6+ii} = ['r_ij' num2str(ii) ' = ' num2str(mdata.r_ij(ii)) ' m; // Specific product of inertia'];
    end
    
    wavefreq = 'FrequencySet1 = FrequencySet(FrequencyTypeFrequency, Array(';
    for ii=1:length(waves(:,1))-1
        wavefreq = [wavefreq num2str(waves(ii,1)) ' rad/s,'];
    end
    data{26} = [wavefreq num2str(waves(end,1)) ' rad/s));'];

    %fidH2 = fopen('C:\Users\Vetle\OneDrive  NTNU\Emner\MASTER\tests.js','w');
    fidH2 = fopen('C:\DNVGL\Workspaces\HydroD\HydroD_fromMatlab.js','w');
    for ii = 1:numel(data)
            fprintf(fidH2,'%s\n', data{ii});
    end
    status=fclose(fidH2);
    if status ~= 0
        fprintf('Did not close file!\n');
        control = false;
    end

elseif run == 2
    %% HydroD additional damping and WadamRun2 
    fidH3 = fopen('C:\Users\Vetle\OneDrive  NTNU\Emner\MASTER\additionalDamping.js','r');
    A = textscan(fidH3,'%s','Delimiter','\n');
    data = A{1};
    status=fclose(fidH3);
    if status ~= 0
        fprintf('Did not close file!\n');
        control = false;
    end
    clear A;

    % Change input data in HydroD command file
    % Writing Morison damping matrix in line 18-53
    for r=1:6
        for c=1:6
            rs = num2str(r);
            cs = num2str(c);
            if abs(Bex(r,c)) < 0.1
                Bexs = '0';
            else
                Bexs = num2str(Bex(r,c));
            end
            if r <= 3 && c <= 3
                data{11+6*r+c} = ['DampingMatrix1.setTranslationalTerm(' rs ',' cs ',' Bexs ');'];
            elseif r > 3 && c > 3
                data{11+6*r+c} = ['DampingMatrix1.setRotationalTerm(' rs ',' cs ',' Bexs ');'];
            else 
                data{11+6*r+c} = ['DampingMatrix1.setCoupledTerm(' rs ',' cs ',' Bexs ');'];
            end
        end
    end

    fidH3 = fopen('C:\DNVGL\Workspaces\HydroD\HydroD_addDamping.js','w');
    for ii = 1:numel(data)
            fprintf(fidH3,'%s\n', data{ii});
    end
    status=fclose(fidH3);
    if status ~= 0
        fprintf('Did not close file!\n');
        control = false;
    end
else
    disp('Invalid run number in writeSesamFiles');
    control = false;
end
    
end % Function